#!/sbin/sh
nikGappsLog="/tmp/NikGapps.log"
configValue="$1"
nikgapps_config_file_name="$2"
product_prefix=""
logDir="/tmp/NikGapps/logs"
nikGappsDir="/sdcard/NikGapps"
recoveryLog=/tmp/recovery.log
datetime=$(date +%Y_%m_%d_%H_%M_%S)
nikGappsLogFile="NikGapps_logs_$datetime.tar.gz"
install_partition="/system"
abort_in_installer() {
  ui_print "$1"
  addToLog "$1"
  copy_installer_logs
  exit 1
}

addToLog() {
  echo "$1" >>$nikGappsLog
}

beginswith() {
  case $2 in
  "$1"*)
    echo true
    ;;
  *)
    echo false
    ;;
  esac
}

# ui_print "<message>" ["<message 2>" ...]
ui_print() {
  until [ ! "$1" ]; do
    echo -e "ui_print $1\nui_print" >>"$OUTFD"
    addToLog "$1"
    shift
  done
}

copy_file() {
  mkdir -p "$(dirname "$3")"
  addToLog "- Unzipping $1"
  addToLog "  -> copying $2"
  addToLog "  -> to $3"
  unzip -o "$1" "$2" -p >"$3"
  if [ ! -f "$3" ] ; then
    addToLog "- Failed to write $3"
    abort_in_installer "Installation Failed! Looks like Storage space is full!"
#  following can be added if file gets written with 0 bytes so file exists but it is corrupted
#  elif [ ! -s "$3" ]; then
#    addToLog "- $3 is blank"
#    abort_in_installer "Installation Failed! Looks like file writing isn't working"
  fi
}

copy_installer_logs() {
  ui_print "- Copying logs to $nikGappsDir/logs"
  cp -f "$recoveryLog" "$logDir/recovery.log"
  cp -f "$nikGappsLog" "$logDir/NikGapps.log"
  cp -f "$system/build.prop" "$logDir/build.prop"
  cd $logDir
  rm -rf $nikGappsDir/logs
  tar -cz -f "/tmp/$nikGappsLogFile" *
  mkdir -p $nikGappsDir/logs
  cp -f /tmp/"$nikGappsLogFile" $nikGappsDir/logs/"$nikGappsLogFile"
  cd /
}

set_perm() {
  uid=$1
  gid=$2
  mod=$3
  shift 3
  chown $uid.$gid "$@"
  chown $uid:$gid "$@"
  chmod $mod "$@"
}

delete_recursive() {
  if [ "$configValue" -eq 2 ]; then
    addToLog "- Not deleting $@"
  else
    addToLog "- rm -rf $@"
    rm -rf "$@"
  fi
}

delete_package() {
  pkg_title="$1"
  pkg_package_name="$2"
  addToLog "- Deleting package $pkg_title and $pkg_package_name"
  delete_recursive "$system/product/app/$1"
  delete_recursive "$system/app/$1"
#  addDeletePathToAddon "app/$1"
  delete_recursive "$system/product/priv-app/$1"
  delete_recursive "$system/priv-app/$1"
#  addDeletePathToAddon "priv-app/$1"
#  rm -rf "/data/app/$pkg_package_name"*
}

get_file_prop() {
  grep -m1 "^$2=" "$1" | cut -d= -f2
}

ReadConfigValue() {
  value=$(sed -e '/^[[:blank:]]*#/d;s/[\t\n\r ]//g;/^$/d' "$2" | grep "^$1=" | cut -d'=' -f 2)
  echo "$value"
  return $?
}

androidVersion=$(get_file_prop "$system/build.prop" "ro.build.version.release")
case "$androidVersion" in
"10")
  product="/product"
  product_prefix="product/"
  ;;
"9")
  product=""
  ;;
"*")
  product=""
  ;;
esac
if [ -f "$nikgapps_config_file_name" ]; then
    val=$(ReadConfigValue "InstallPartition" "$nikgapps_config_file_name")
    addToLog "- Config Value for InstallPartition is $val"
    install_partition=$system$product
    startswith=$(beginswith / "$val")
    if [ "$val" == "system" ]; then
      product=""
      product_prefix=""
    elif [ "$val" == "product" ]; then
      product="/product"
      product_prefix="product/"
    elif [ "$val" == "data" ]; then
      install_partition="/data/extra"
    elif [ "$startswith" == "true" ]; then
      install_partition=$val
      if echo "$val" | grep '/product'; then
        product_prefix="product/"
        addToLog "- /product is present in $install_partition"
      else
        product_prefix=""
        addToLog "- /product is not present in $install_partition"
      fi
    else
      addToLog "- Config Value for InstallPartition not present"
    fi
    addToLog "- InstallPartition = $install_partition"
fi

addDeletePathToAddon() {
  if [ "$configValue" -eq 2 ]; then
    addToLog "- Not creating addon.d script for $@"
  else
    addToLog "- Creating addon.d script for $@"
    deletePath="$1"
    echo "delete=$deletePath" >>/tmp/addon/"$packagePath"
  fi
}
packagePath=GoogleContactsSyncAdapterFiles
delete_package "GoogleContactsSyncAdapter" "com.google.android.syncadapters.contacts"
mkdir -p "$install_partition/app"
set_perm 1000 1000 0755 "$install_partition/app"
mkdir -p "$install_partition/app/GoogleContactsSyncAdapter"
set_perm 1000 1000 0755 "$install_partition/app/GoogleContactsSyncAdapter"
copy_file "$pkgFile" "___system___product___app___GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk" "$install_partition/app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk"
set_perm 0 0 0644 "$install_partition/app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk"
installPath=$product_prefix"app/GoogleContactsSyncAdapter/GoogleContactsSyncAdapter.apk"
echo "install=$installPath" >> /tmp/addon/$packagePath
chmod 755 "/tmp/AFZCScripts/addon";
. /tmp/AFZCScripts/addon "$OFD" "GoogleContactsSyncAdapter" "/tmp/addon/$packagePath"
cp -f "$system/addon.d/GoogleContactsSyncAdapter.sh" "$logDir/GoogleContactsSyncAdapter.sh"
cp -f "/tmp/addon/$packagePath" "$logDir/$packagePath.addon"
rm -rf "/tmp/addon/$packagePath"
