#!/sbin/sh
nikGappsLog="/tmp/NikGapps.log"
configValue="$1"
nikgapps_config_file_name="$2"
product_prefix=""
logDir="/tmp/NikGapps/logs"
nikGappsDir="/sdcard/NikGapps"
recoveryLog=/tmp/recovery.log
datetime=$(date +%Y_%m_%d_%H_%M_%S)
nikGappsLogFile="NikGapps_logs_$datetime.tar.gz"
install_partition="/system"
abort_in_installer() {
  ui_print "$1"
  addToLog "$1"
  copy_installer_logs
  exit 1
}

addToLog() {
  echo "$1" >>$nikGappsLog
}

beginswith() {
  case $2 in
  "$1"*)
    echo true
    ;;
  *)
    echo false
    ;;
  esac
}

# ui_print "<message>" ["<message 2>" ...]
ui_print() {
  until [ ! "$1" ]; do
    echo -e "ui_print $1\nui_print" >>"$OUTFD"
    addToLog "$1"
    shift
  done
}

copy_file() {
  mkdir -p "$(dirname "$3")"
  addToLog "- Unzipping $1"
  addToLog "  -> copying $2"
  addToLog "  -> to $3"
  unzip -o "$1" "$2" -p >"$3"
  if [ ! -f "$3" ] ; then
    addToLog "- Failed to write $3"
    abort_in_installer "Installation Failed! Looks like Storage space is full!"
#  following can be added if file gets written with 0 bytes so file exists but it is corrupted
#  elif [ ! -s "$3" ]; then
#    addToLog "- $3 is blank"
#    abort_in_installer "Installation Failed! Looks like file writing isn't working"
  fi
}

copy_installer_logs() {
  ui_print "- Copying logs to $nikGappsDir/logs"
  cp -f "$recoveryLog" "$logDir/recovery.log"
  cp -f "$nikGappsLog" "$logDir/NikGapps.log"
  cp -f "$system/build.prop" "$logDir/build.prop"
  cd $logDir
  rm -rf $nikGappsDir/logs
  tar -cz -f "/tmp/$nikGappsLogFile" *
  mkdir -p $nikGappsDir/logs
  cp -f /tmp/"$nikGappsLogFile" $nikGappsDir/logs/"$nikGappsLogFile"
  cd /
}

set_perm() {
  uid=$1
  gid=$2
  mod=$3
  shift 3
  chown $uid.$gid "$@"
  chown $uid:$gid "$@"
  chmod $mod "$@"
}

delete_recursive() {
  if [ "$configValue" -eq 2 ]; then
    addToLog "- Not deleting $@"
  else
    addToLog "- rm -rf $@"
    rm -rf "$@"
  fi
}

delete_package() {
  pkg_title="$1"
  pkg_package_name="$2"
  addToLog "- Deleting package $pkg_title and $pkg_package_name"
  delete_recursive "$system/product/app/$1"
  delete_recursive "$system/app/$1"
#  addDeletePathToAddon "app/$1"
  delete_recursive "$system/product/priv-app/$1"
  delete_recursive "$system/priv-app/$1"
#  addDeletePathToAddon "priv-app/$1"
#  rm -rf "/data/app/$pkg_package_name"*
}

get_file_prop() {
  grep -m1 "^$2=" "$1" | cut -d= -f2
}

ReadConfigValue() {
  value=$(sed -e '/^[[:blank:]]*#/d;s/[\t\n\r ]//g;/^$/d' "$2" | grep "^$1=" | cut -d'=' -f 2)
  echo "$value"
  return $?
}

androidVersion=$(get_file_prop "$system/build.prop" "ro.build.version.release")
case "$androidVersion" in
"10")
  product="/product"
  product_prefix="product/"
  ;;
"9")
  product=""
  ;;
"*")
  product=""
  ;;
esac
if [ -f "$nikgapps_config_file_name" ]; then
    val=$(ReadConfigValue "InstallPartition" "$nikgapps_config_file_name")
    addToLog "- Config Value for InstallPartition is $val"
    install_partition=$system$product
    startswith=$(beginswith / "$val")
    if [ "$val" == "system" ]; then
      product=""
      product_prefix=""
    elif [ "$val" == "product" ]; then
      product="/product"
      product_prefix="product/"
    elif [ "$val" == "data" ]; then
      install_partition="/data/extra"
    elif [ "$startswith" == "true" ]; then
      install_partition=$val
      if echo "$val" | grep '/product'; then
        product_prefix="product/"
        addToLog "- /product is present in $install_partition"
      else
        product_prefix=""
        addToLog "- /product is not present in $install_partition"
      fi
    else
      addToLog "- Config Value for InstallPartition not present"
    fi
    addToLog "- InstallPartition = $install_partition"
fi

addDeletePathToAddon() {
  if [ "$configValue" -eq 2 ]; then
    addToLog "- Not creating addon.d script for $@"
  else
    addToLog "- Creating addon.d script for $@"
    deletePath="$1"
    echo "delete=$deletePath" >>/tmp/addon/"$packagePath"
  fi
}
packagePath=ExtraFilesFiles
mkdir -p "$install_partition/etc/default-permissions"
set_perm 1000 1000 0755 "$install_partition/etc/default-permissions"
mkdir -p "$install_partition/etc/permissions"
set_perm 1000 1000 0755 "$install_partition/etc/permissions"
mkdir -p "$install_partition/etc/sysconfig"
set_perm 1000 1000 0755 "$install_partition/etc/sysconfig"
mkdir -p "$install_partition/lib64"
set_perm 1000 1000 0755 "$install_partition/lib64"
copy_file "$pkgFile" "___system___product___etc___default-permissions/default-permissions.xml" "$install_partition/etc/default-permissions/default-permissions.xml"
set_perm 0 0 0644 "$install_partition/etc/default-permissions/default-permissions.xml"
installPath=$product_prefix"etc/default-permissions/default-permissions.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___default-permissions/opengapps-permissions.xml" "$install_partition/etc/default-permissions/opengapps-permissions.xml"
set_perm 0 0 0644 "$install_partition/etc/default-permissions/opengapps-permissions.xml"
installPath=$product_prefix"etc/default-permissions/opengapps-permissions.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/com.google.android.dialer.support.xml" "$install_partition/etc/permissions/com.google.android.dialer.support.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/com.google.android.dialer.support.xml"
installPath=$product_prefix"etc/permissions/com.google.android.dialer.support.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/com.google.android.maps.xml" "$install_partition/etc/permissions/com.google.android.maps.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/com.google.android.maps.xml"
installPath=$product_prefix"etc/permissions/com.google.android.maps.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/com.google.android.media.effects.xml" "$install_partition/etc/permissions/com.google.android.media.effects.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/com.google.android.media.effects.xml"
installPath=$product_prefix"etc/permissions/com.google.android.media.effects.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/com.google.widevine.software.drm.xml" "$install_partition/etc/permissions/com.google.widevine.software.drm.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/com.google.widevine.software.drm.xml"
installPath=$product_prefix"etc/permissions/com.google.widevine.software.drm.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/privapp-permissions-google-p.xml" "$install_partition/etc/permissions/privapp-permissions-google-p.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/privapp-permissions-google-p.xml"
installPath=$product_prefix"etc/permissions/privapp-permissions-google-p.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/privapp-permissions-google-ps.xml" "$install_partition/etc/permissions/privapp-permissions-google-ps.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/privapp-permissions-google-ps.xml"
installPath=$product_prefix"etc/permissions/privapp-permissions-google-ps.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/privapp-permissions-google.xml" "$install_partition/etc/permissions/privapp-permissions-google.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/privapp-permissions-google.xml"
installPath=$product_prefix"etc/permissions/privapp-permissions-google.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/privapp-permissions-hotword.xml" "$install_partition/etc/permissions/privapp-permissions-hotword.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/privapp-permissions-hotword.xml"
installPath=$product_prefix"etc/permissions/privapp-permissions-hotword.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___permissions/split-permissions-google.xml" "$install_partition/etc/permissions/split-permissions-google.xml"
set_perm 0 0 0644 "$install_partition/etc/permissions/split-permissions-google.xml"
installPath=$product_prefix"etc/permissions/split-permissions-google.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/dialer_experience.xml" "$install_partition/etc/sysconfig/dialer_experience.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/dialer_experience.xml"
installPath=$product_prefix"etc/sysconfig/dialer_experience.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/google-hiddenapi-package-whitelist.xml" "$install_partition/etc/sysconfig/google-hiddenapi-package-whitelist.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/google-hiddenapi-package-whitelist.xml"
installPath=$product_prefix"etc/sysconfig/google-hiddenapi-package-whitelist.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/google.xml" "$install_partition/etc/sysconfig/google.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/google.xml"
installPath=$product_prefix"etc/sysconfig/google.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/google_build.xml" "$install_partition/etc/sysconfig/google_build.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/google_build.xml"
installPath=$product_prefix"etc/sysconfig/google_build.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/google_vr_build.xml" "$install_partition/etc/sysconfig/google_vr_build.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/google_vr_build.xml"
installPath=$product_prefix"etc/sysconfig/google_vr_build.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/nexus.xml" "$install_partition/etc/sysconfig/nexus.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/nexus.xml"
installPath=$product_prefix"etc/sysconfig/nexus.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/pixel_2019_exclusive.xml" "$install_partition/etc/sysconfig/pixel_2019_exclusive.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/pixel_2019_exclusive.xml"
installPath=$product_prefix"etc/sysconfig/pixel_2019_exclusive.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/pixel_experience_2017.xml" "$install_partition/etc/sysconfig/pixel_experience_2017.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/pixel_experience_2017.xml"
installPath=$product_prefix"etc/sysconfig/pixel_experience_2017.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/pixel_experience_2018.xml" "$install_partition/etc/sysconfig/pixel_experience_2018.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/pixel_experience_2018.xml"
installPath=$product_prefix"etc/sysconfig/pixel_experience_2018.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/pixel_experience_2019.xml" "$install_partition/etc/sysconfig/pixel_experience_2019.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/pixel_experience_2019.xml"
installPath=$product_prefix"etc/sysconfig/pixel_experience_2019.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___etc___sysconfig/pixel_experience_2019_midyear.xml" "$install_partition/etc/sysconfig/pixel_experience_2019_midyear.xml"
set_perm 0 0 0644 "$install_partition/etc/sysconfig/pixel_experience_2019_midyear.xml"
installPath=$product_prefix"etc/sysconfig/pixel_experience_2019_midyear.xml"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___framework/com.google.android.dialer.support.jar" "$install_partition/framework/com.google.android.dialer.support.jar"
set_perm 0 0 0644 "$install_partition/framework/com.google.android.dialer.support.jar"
installPath=$product_prefix"framework/com.google.android.dialer.support.jar"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___framework/com.google.android.maps.jar" "$install_partition/framework/com.google.android.maps.jar"
set_perm 0 0 0644 "$install_partition/framework/com.google.android.maps.jar"
installPath=$product_prefix"framework/com.google.android.maps.jar"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___framework/com.google.android.media.effects.jar" "$install_partition/framework/com.google.android.media.effects.jar"
set_perm 0 0 0644 "$install_partition/framework/com.google.android.media.effects.jar"
installPath=$product_prefix"framework/com.google.android.media.effects.jar"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___framework/com.google.widevine.software.drm.jar" "$install_partition/framework/com.google.widevine.software.drm.jar"
set_perm 0 0 0644 "$install_partition/framework/com.google.widevine.software.drm.jar"
installPath=$product_prefix"framework/com.google.widevine.software.drm.jar"
echo "install=$installPath" >> /tmp/addon/$packagePath
copy_file "$pkgFile" "___system___product___lib64/libgdx.so" "$install_partition/lib64/libgdx.so"
set_perm 0 0 0644 "$install_partition/lib64/libgdx.so"
installPath=$product_prefix"lib64/libgdx.so"
echo "install=$installPath" >> /tmp/addon/$packagePath
chmod 755 "/tmp/AFZCScripts/addon";
. /tmp/AFZCScripts/addon "$OFD" "ExtraFiles" "/tmp/addon/$packagePath"
cp -f "$system/addon.d/ExtraFiles.sh" "$logDir/ExtraFiles.sh"
cp -f "/tmp/addon/$packagePath" "$logDir/$packagePath.addon"
rm -rf "/tmp/addon/$packagePath"
